==> zio-aws-applicationautoscaling_3-5.17.130.7-sources.jar: zio/aws/applicationautoscaling/model/package.scala <==
package zio.aws.applicationautoscaling
import zio.aws.applicationautoscaling.model.primitives.ResourceIdMaxLen1600
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.applicationautoscaling.model.primitives.PolicyName.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object Cooldown extends Subtype[Int]
    type Cooldown =
      zio.aws.applicationautoscaling.model.primitives.Cooldown.Type
    object DisableScaleIn extends Subtype[Boolean]
    type DisableScaleIn =
      zio.aws.applicationautoscaling.model.primitives.DisableScaleIn.Type
    object MaxResults extends Subtype[Int]
    type MaxResults =
      zio.aws.applicationautoscaling.model.primitives.MaxResults.Type
    object MetricDimensionName extends Subtype[String]
    type MetricDimensionName =
      zio.aws.applicationautoscaling.model.primitives.MetricDimensionName.Type
    object MetricDimensionValue extends Subtype[String]
    type MetricDimensionValue =
      zio.aws.applicationautoscaling.model.primitives.MetricDimensionValue.Type
    object MetricName extends Subtype[String]
    type MetricName =
      zio.aws.applicationautoscaling.model.primitives.MetricName.Type
    object MetricNamespace extends Subtype[String]
    type MetricNamespace =
      zio.aws.applicationautoscaling.model.primitives.MetricNamespace.Type
    object MetricScale extends Subtype[Double]
    type MetricScale =
      zio.aws.applicationautoscaling.model.primitives.MetricScale.Type
    object MetricUnit extends Subtype[String]
    type MetricUnit =
      zio.aws.applicationautoscaling.model.primitives.MetricUnit.Type
    object MinAdjustmentMagnitude extends Subtype[Int]
    type MinAdjustmentMagnitude =
      zio.aws.applicationautoscaling.model.primitives.MinAdjustmentMagnitude.Type
    object PolicyName extends Subtype[String]
    type PolicyName =
      zio.aws.applicationautoscaling.model.primitives.PolicyName.Type
    object ResourceCapacity extends Subtype[Int]
    type ResourceCapacity =
      zio.aws.applicationautoscaling.model.primitives.ResourceCapacity.Type
    object ResourceId extends Subtype[String]
    type ResourceId =
      zio.aws.applicationautoscaling.model.primitives.ResourceId.Type
    object ResourceIdMaxLen1600 extends Subtype[String]
    type ResourceIdMaxLen1600 =
      zio.aws.applicationautoscaling.model.primitives.ResourceIdMaxLen1600.Type
    object ResourceLabel extends Subtype[String]
    type ResourceLabel =
      zio.aws.applicationautoscaling.model.primitives.ResourceLabel.Type
    object ScalingAdjustment extends Subtype[Int]
    type ScalingAdjustment =
      zio.aws.applicationautoscaling.model.primitives.ScalingAdjustment.Type
    object ScalingSuspended extends Subtype[Boolean]
    type ScalingSuspended =
      zio.aws.applicationautoscaling.model.primitives.ScalingSuspended.Type
    object ScheduledActionName extends Subtype[String]
    type ScheduledActionName =
      zio.aws.applicationautoscaling.model.primitives.ScheduledActionName.Type
    object TimestampType extends Subtype[Instant]
    type TimestampType =
      zio.aws.applicationautoscaling.model.primitives.TimestampType.Type
    object XmlString extends Subtype[String]
    type XmlString =
      zio.aws.applicationautoscaling.model.primitives.XmlString.Type
  }
  type Alarms = List[zio.aws.applicationautoscaling.model.Alarm]
  type MetricDimensions =
    List[zio.aws.applicationautoscaling.model.MetricDimension]
  type ResourceIdsMaxLen1600 = List[ResourceIdMaxLen1600]
  type ScalableTargets =
    List[zio.aws.applicationautoscaling.model.ScalableTarget]
  type ScalingActivities =
    List[zio.aws.applicationautoscaling.model.ScalingActivity]
  type ScalingPolicies =
    List[zio.aws.applicationautoscaling.model.ScalingPolicy]
  type ScheduledActions =
    List[zio.aws.applicationautoscaling.model.ScheduledAction]
  type StepAdjustments =
    List[zio.aws.applicationautoscaling.model.StepAdjustment]
}

==> zio-aws-applicationautoscaling_3-5.19.17.1-sources.jar: zio/aws/applicationautoscaling/model/package.scala <==
package zio.aws.applicationautoscaling
import zio.aws.applicationautoscaling.model.primitives.ResourceIdMaxLen1600
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.applicationautoscaling.model.primitives.IncludeNotScaledActivities.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object Cooldown extends Subtype[Int]
    type Cooldown =
      zio.aws.applicationautoscaling.model.primitives.Cooldown.Type
    object DisableScaleIn extends Subtype[Boolean]
    type DisableScaleIn =
      zio.aws.applicationautoscaling.model.primitives.DisableScaleIn.Type
    object IncludeNotScaledActivities extends Subtype[Boolean]
    type IncludeNotScaledActivities =
      zio.aws.applicationautoscaling.model.primitives.IncludeNotScaledActivities.Type
    object MaxResults extends Subtype[Int]
    type MaxResults =
      zio.aws.applicationautoscaling.model.primitives.MaxResults.Type
    object MetricDimensionName extends Subtype[String]
    type MetricDimensionName =
      zio.aws.applicationautoscaling.model.primitives.MetricDimensionName.Type
    object MetricDimensionValue extends Subtype[String]
    type MetricDimensionValue =
      zio.aws.applicationautoscaling.model.primitives.MetricDimensionValue.Type
    object MetricName extends Subtype[String]
    type MetricName =
      zio.aws.applicationautoscaling.model.primitives.MetricName.Type
    object MetricNamespace extends Subtype[String]
    type MetricNamespace =
      zio.aws.applicationautoscaling.model.primitives.MetricNamespace.Type
    object MetricScale extends Subtype[Double]
    type MetricScale =
      zio.aws.applicationautoscaling.model.primitives.MetricScale.Type
    object MetricUnit extends Subtype[String]
    type MetricUnit =
      zio.aws.applicationautoscaling.model.primitives.MetricUnit.Type
    object MinAdjustmentMagnitude extends Subtype[Int]
    type MinAdjustmentMagnitude =
      zio.aws.applicationautoscaling.model.primitives.MinAdjustmentMagnitude.Type
    object PolicyName extends Subtype[String]
    type PolicyName =
      zio.aws.applicationautoscaling.model.primitives.PolicyName.Type
    object ResourceCapacity extends Subtype[Int]
    type ResourceCapacity =
      zio.aws.applicationautoscaling.model.primitives.ResourceCapacity.Type
    object ResourceId extends Subtype[String]
    type ResourceId =
      zio.aws.applicationautoscaling.model.primitives.ResourceId.Type
    object ResourceIdMaxLen1600 extends Subtype[String]
    type ResourceIdMaxLen1600 =
      zio.aws.applicationautoscaling.model.primitives.ResourceIdMaxLen1600.Type
    object ResourceLabel extends Subtype[String]
    type ResourceLabel =
      zio.aws.applicationautoscaling.model.primitives.ResourceLabel.Type
    object ScalingAdjustment extends Subtype[Int]
    type ScalingAdjustment =
      zio.aws.applicationautoscaling.model.primitives.ScalingAdjustment.Type
    object ScalingSuspended extends Subtype[Boolean]
    type ScalingSuspended =
      zio.aws.applicationautoscaling.model.primitives.ScalingSuspended.Type
    object ScheduledActionName extends Subtype[String]
    type ScheduledActionName =
      zio.aws.applicationautoscaling.model.primitives.ScheduledActionName.Type
    object TimestampType extends Subtype[Instant]
    type TimestampType =
      zio.aws.applicationautoscaling.model.primitives.TimestampType.Type
    object XmlString extends Subtype[String]
    type XmlString =
      zio.aws.applicationautoscaling.model.primitives.XmlString.Type
  }
  type Alarms = List[zio.aws.applicationautoscaling.model.Alarm]
  type MetricDimensions =
    List[zio.aws.applicationautoscaling.model.MetricDimension]
  type NotScaledReasons =
    List[zio.aws.applicationautoscaling.model.NotScaledReason]
  type ResourceIdsMaxLen1600 = List[ResourceIdMaxLen1600]
  type ScalableTargets =
    List[zio.aws.applicationautoscaling.model.ScalableTarget]
  type ScalingActivities =
    List[zio.aws.applicationautoscaling.model.ScalingActivity]
  type ScalingPolicies =
    List[zio.aws.applicationautoscaling.model.ScalingPolicy]
  type ScheduledActions =
    List[zio.aws.applicationautoscaling.model.ScheduledAction]
  type StepAdjustments =
    List[zio.aws.applicationautoscaling.model.StepAdjustment]
}
